import pandas as pd

def read_host_csv(prefix, hostname, startTime, basename, fullname, archive_fid=None):
    fullpath= '%s_%s/%s_%s_%s' % (basename, prefix, hostname, fullname, startTime)
    if archive_fid is None:
        with open(fullpath) as file_id:
            data = pd.read_csv(fullpath,sep=' ', skipinitialspace=True)
    else:
        with archive_fid.open(fullpath) as file_id:
            data = pd.read_csv(file_id,sep=' ')
    data = data.dropna(axis='columns')
    return data

def read_run_csv(prefix, hostname, startTime, basename, fullname, hostlist, archive_fid=None):
    return [read_host_csv(prefix, host, startTime, basename, fullname, archive_fid) for host in hostlist.split(';')]
       
def read_bundle_csv(prefix, bundle, archive_fid=None):
    'Reads mojitO/S-like files associated to a bundle'
    csv_data = [read_run_csv(prefix, row.hostname, row.startTime, row.basename, row.fullname, row.hostlist, archive_fid) 
                    for index, row in bundle.iterrows()]
    return csv_data




import json
import pandas as pd

## Power
def read_run_list(prefix, hostname, startTime, basename, fullname, hostlist=None, archive_fid=None):
    fullpath= '%s_%s/%s_%s_%s' % (basename, prefix, hostname, fullname, startTime)
    result = []

    try:
        if archive_fid is None:
            with open(fullpath) as file_id:
                raw_data = json.loads(file_id.read())
        else:
            with archive_fid.open(fullpath) as file_id:
                raw_data = json.loads(file_id.read())
    
        data = {host:(timestamp, values) for (host, timestamp, values) in raw_data}
    
        for host in hostlist.split(';'):
            name, _ = host.split('.', maxsplit=1)
            df = pd.DataFrame(list(data[name])).transpose()
            df.columns = ["#timestamp", prefix]
            result.append(df)
    except:
        pass
    
    return result

def read_bundle_list(prefix, bundle, archive_fid=None):
    'Reads the power files associated to a bundle'    
    list_data = [read_run_list(prefix, row.hostname, row.startTime, row.basename, row.fullname, row.hostlist, archive_fid) 
                    for index, row in bundle.iterrows()]
    return list_data

